==> chromium-44.0.2403.128.tar.xz: chromium-44.0.2403.128/chrome/browser/chromeos/file_system_provider/operations/add_watcher.cc <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/chromeos/file_system_provider/operations/add_watcher.h"

#include <string>

#include "chrome/common/extensions/api/file_system_provider.h"
#include "chrome/common/extensions/api/file_system_provider_internal.h"

namespace chromeos {
namespace file_system_provider {
namespace operations {

AddWatcher::AddWatcher(extensions::EventRouter* event_router,
                       const ProvidedFileSystemInfo& file_system_info,
                       const base::FilePath& entry_path,
                       bool recursive,
                       const storage::AsyncFileUtil::StatusCallback& callback)
    : Operation(event_router, file_system_info),
      entry_path_(entry_path),
      recursive_(recursive),
      callback_(callback) {
}

AddWatcher::~AddWatcher() {
}

bool AddWatcher::Execute(int request_id) {
  using extensions::api::file_system_provider::AddWatcherRequestedOptions;

  AddWatcherRequestedOptions options;
  options.file_system_id = file_system_info_.file_system_id();
  options.request_id = request_id;
  options.entry_path = entry_path_.AsUTF8Unsafe();
  options.recursive = recursive_;

  return SendEvent(
      request_id,
      extensions::api::file_system_provider::OnAddWatcherRequested::kEventName,
      extensions::api::file_system_provider::OnAddWatcherRequested::Create(
          options));
}

void AddWatcher::OnSuccess(int /* request_id */,
                           scoped_ptr<RequestValue> /* result */,
                           bool has_more) {
  callback_.Run(base::File::FILE_OK);
}

void AddWatcher::OnError(int /* request_id */,
                         scoped_ptr<RequestValue> /* result */,
                         base::File::Error error) {
  callback_.Run(error);
}

}  // namespace operations
}  // namespace file_system_provider
}  // namespace chromeos

==> chromium-54.0.2840.42.tar.xz: chromium-54.0.2840.42/chrome/browser/chromeos/file_system_provider/operations/add_watcher.cc <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/chromeos/file_system_provider/operations/add_watcher.h"

#include <string>

#include "chrome/common/extensions/api/file_system_provider.h"
#include "chrome/common/extensions/api/file_system_provider_internal.h"

namespace chromeos {
namespace file_system_provider {
namespace operations {

AddWatcher::AddWatcher(extensions::EventRouter* event_router,
                       const ProvidedFileSystemInfo& file_system_info,
                       const base::FilePath& entry_path,
                       bool recursive,
                       const storage::AsyncFileUtil::StatusCallback& callback)
    : Operation(event_router, file_system_info),
      entry_path_(entry_path),
      recursive_(recursive),
      callback_(callback) {
}

AddWatcher::~AddWatcher() {
}

bool AddWatcher::Execute(int request_id) {
  using extensions::api::file_system_provider::AddWatcherRequestedOptions;

  AddWatcherRequestedOptions options;
  options.file_system_id = file_system_info_.file_system_id();
  options.request_id = request_id;
  options.entry_path = entry_path_.AsUTF8Unsafe();
  options.recursive = recursive_;

  return SendEvent(
      request_id,
      extensions::events::FILE_SYSTEM_PROVIDER_ON_ADD_WATCHER_REQUESTED,
      extensions::api::file_system_provider::OnAddWatcherRequested::kEventName,
      extensions::api::file_system_provider::OnAddWatcherRequested::Create(
          options));
}

void AddWatcher::OnSuccess(int /* request_id */,
                           std::unique_ptr<RequestValue> /* result */,
                           bool has_more) {
  callback_.Run(base::File::FILE_OK);
}

void AddWatcher::OnError(int /* request_id */,
                         std::unique_ptr<RequestValue> /* result */,
                         base::File::Error error) {
  callback_.Run(error);
}

}  // namespace operations
}  // namespace file_system_provider
}  // namespace chromeos
